<?php

namespace Unific\Connector\Plugin;

use Unific\Connector\Helper\Settings;

class CategoryPlugin extends AbstractPlugin
{
    protected $categoryDataHelper;

    /**
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     * @param \Unific\Connector\Helper\Hmac $hmacHelper
     * @param \Unific\Connector\Helper\Message\Queue $queueHelper
     * @param \Magento\Framework\App\ProductMetadataInterface $productMetadata
     * @param \Magento\Framework\Module\ModuleListInterface $moduleList
     * @param \Unific\Connector\Helper\Data\Category $categoryDataHelper
     */
    public function __construct(
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Unific\Connector\Helper\Hmac $hmacHelper,
        \Unific\Connector\Helper\Message\Queue $queueHelper,
        \Magento\Framework\App\ProductMetadataInterface $productMetadata,
        \Magento\Framework\Module\ModuleListInterface $moduleList,
        \Unific\Connector\Helper\Data\Category $categoryDataHelper
    ) {
        parent::__construct(
            $scopeConfig,
            $hmacHelper,
            $queueHelper,
            $productMetadata,
            $moduleList
        );

        $this->categoryDataHelper = $categoryDataHelper;
    }

    /**
     * @param \Magento\Catalog\Model\Category $subject
     * @return \Magento\Catalog\Model\Category
     */
    public function afterSave(\Magento\Catalog\Model\Category $subject)
    {
        if ($this->scopeConfig->getValue('unific/connector/enabled') == 1) {
            $integrationSubject = 'category/create';

            if ($subject->getCreatedAt() != $subject->getUpdatedAt() && $subject->getUpdatedAt() != null) {
                $integrationSubject = 'category/update';
            }

            $this->categoryDataHelper->setCategory($subject);
            $this->processWebhook(
                $this->categoryDataHelper->getCategoryInfo(),
                $this->scopeConfig->getValue('unific/webhook/category_endpoint'),
                Settings::PRIORITY_CATEGORY,
                $integrationSubject
            );
        }

        return $subject;
    }
}
