<?php

namespace Unific\Connector\Setup;

use Magento\Framework\Setup\UpgradeDataInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;

/**
 * Class UpgradeData
 * @package Unific\Connector\Setup
 */
class UpgradeData implements UpgradeDataInterface
{
    /**
     * @var \Unific\Connector\Helper\Data
     */
    protected $unificHelper;

    /**
     * @var \Unific\Connector\Helper\Hmac
     */
    protected $hmacHelper;

    /**
     * @var \Magento\Framework\App\Config\Storage\WriterInterface
     */
    protected $configWriter;

    /**
     * @var \Magento\Framework\App\Config\ScopeConfigInterface
     */
    protected $scopeConfig;

    private $secretKey = 'unific/hmac/hmacSecret';

    /**
     * Init
     *
     * @param \Unific\Connector\Helper\Data $unificHelper
     * @param \Unific\Connector\Helper\Hmac $hmacHelper
     * @param \Magento\Framework\App\Config\Storage\WriterInterface $configWriter
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     */
    public function __construct(
        \Unific\Connector\Helper\Data $unificHelper,
        \Unific\Connector\Helper\Hmac $hmacHelper,
        \Magento\Framework\App\Config\Storage\WriterInterface $configWriter,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
    ) {
        $this->unificHelper = $unificHelper;
        $this->hmacHelper = $hmacHelper;
        $this->configWriter = $configWriter;
        $this->scopeConfig = $scopeConfig;
    }

    /**
     * @param ModuleDataSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function upgrade(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        $this->unificHelper->createApiUser();

        if ($this->scopeConfig->getValue($this->secretKey, \Magento\Store\Model\ScopeInterface::SCOPE_STORE) == null ||
            $this->scopeConfig->getValue($this->secretKey, \Magento\Store\Model\ScopeInterface::SCOPE_STORE) == '') {
            $this->configWriter->save($this->secretKey, $this->hmacHelper->generateSecret());
        }

        $setup->endSetup();
    }
}
